@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021-2022 -- leonerd@leonerd.org.uk
 
-package Object::Pad::ClassAttr::Struct 0.04;
+package Object::Pad::ClassAttr::Struct 0.05;
 
 use v5.14;
 use warnings;
@@ -72,6 +72,15 @@ This positional constructor must receive as many positional arguments as there
 are fields in total in the class; even the optional ones. All arguments are
 required here.
 
+I<Since version 0.05> the following options are permitted inside the attribute
+value parentheses:
+
+=head3 :Struct(readonly)
+
+Instances of this class do not permit fields to be modified after
+construction. The accessor is created using the C<:reader> field attribute
+rather than C<:mutator>.
+
 =cut
 
 sub import
